@@ -27,17 +27,27 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 from django.contrib import admin
-from models import Repo, UserRights, GroupRights
+from . import settings
+from .models import Repo
 
-def update_local_files(modeladmin, request, queryset):
+def update_svnserve(modeladmin, request, queryset):
   for obj in queryset:
-    obj.update_local_files()
+    obj.update_svnserve()
+update_svnserve.short_description = 'Update svnserve.conf'
+
+def relocate_path(modeladmin, request, queryset):
+  for obj in queryset:
+    obj.relocate_path()
+    obj.save()
 
 class RepoAdmin(admin.ModelAdmin):
   list_display = ['__unicode__', 'path', 'vcs']
   list_filter = ['vcs']
   search_fields = ['name', 'path']
-  actions = [update_local_files]
+  actions = [
+    update_svnserve,
+    relocate_path,
+  ]
 
   def get_readonly_fields(self, request, obj=None):
     if obj:
@@ -49,14 +59,22 @@ class RepoAdmin(admin.ModelAdmin):
     return instance.abspath
   abspath.short_description = 'Full Path'
 
-class UserRightsAdmin(admin.ModelAdmin):
-  list_display = ['__unicode__', 'repo', 'user', 'rights']
-  search_fields = ['repo__name', 'user__username']
-
-class GroupRightsAdmin(admin.ModelAdmin):
-  list_display = ['__unicode__', 'repo', 'group', 'rights']
-  search_fields = ['repo__name', 'group__name']
-
 admin.site.register(Repo, RepoAdmin)
-admin.site.register(UserRights, UserRightsAdmin)
-admin.site.register(GroupRights, GroupRightsAdmin)
+
+if settings.VCSREPO_USE_USER_RIGHTS:
+  from .models import UserRights
+
+  class UserRightsAdmin(admin.ModelAdmin):
+    list_display = ['__unicode__', 'repo', 'user', 'rights']
+    search_fields = ['repo__name', 'user__username']
+
+  admin.site.register(UserRights, UserRightsAdmin)
+
+if settings.VCSREPO_USE_GROUP_RIGHTS:
+  from .models import GroupRights
+
+  class GroupRightsAdmin(admin.ModelAdmin):
+    list_display = ['__unicode__', 'repo', 'group', 'rights']
+    search_fields = ['repo__name', 'group__name']
+
+  admin.site.register(GroupRights, GroupRightsAdmin)
